Name:           anet
Version:        0.3.4
Release:        5%{?dist}
Summary:        Ada Networking Library

Group:          System Environment/Libraries
License:        GPLv2+ with exceptions
URL:            https://www.codelabs.ch/anet/
Source:         https://www.codelabs.ch/download/libanet-%{version}.tar.bz2
Source2:        https://www.codelabs.ch/download/libanet-%{version}.tar.bz2.sig
Source3:        https://www.codelabs.ch/keys/0xBB793815pub.asc
# Fedora-specific patch to use the directories project:
Patch1:         anet-0.2.2-directories_gpr.patch
# Disable one test that doesn't work in Koji:
Patch2:         anet-0.3.3-no_IPv6_multicast_test.patch
# Build with GPRbuild:
Patch3:         anet-0.3.4-gprbuild.patch

BuildRequires:  gcc-gnat fedora-gnat-project-common make asciidoc ahven-devel
BuildRequires:  gprbuild
BuildRequires:  gnupg2
# Build only on architectures where gcc-gnat is available:
ExclusiveArch:  %{GPRbuild_arches}
# Fails on ppc64le:
# https://bugzilla.redhat.com/show_bug.cgi?id=1419355
ExcludeArch:    ppc64le

%global common_description_en \
Anet is a networking library for the Ada programming language. It supports, \
among other things, IPv6, Unix domain sockets, multicast, raw sockets, link \
layer sockets and Netlink.

%global common_description_sv \
Anet är ett nätverksprogrammeringsbibliotek för programmeringsspråket ada. \
Det har bland annat stöd för IPv6, Unixsocketar, flersändning, råa socketar, \
länklagersocketar och Netlink.

%description %{common_description_en}

%description -l sv %{common_description_sv}


%package devel
Summary:        Development files for Anet
Summary(sv):    Filer för programmering med Anet
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       fedora-gnat-project-common

%description devel %{common_description_en}

The %{name}-devel package contains source code and linking information for
developing applications that use Anet.

%description devel -l sv %{common_description_sv}

Paketet %{name}-devel innehåller källkod och länkningsinformation som behövs
för att utveckla program som använder Anet.


%prep
# Decode the ASCII armor on the keyring.
gpg2 --homedir=nonexistent/dir --yes --output=keyring.gpg --dearmor %{SOURCE3}
# Verify the signature using the decoded keyring.
gpgv2 --homedir=nonexistent/dir --keyring=./keyring.gpg %{SOURCE2} %{SOURCE0}
# (--homedir isn't actually necessary. --dearmor processes only the input file,
# and if --keyring is used and contains a slash, then gpgv2 uses only that
# keyring. Thus neither command will look for a default keyring, but --homedir
# makes extra double sure that no default keyring will be touched in case
# another version of GPG works differently.)
rm keyring.gpg

%setup -q -n libanet-%{version}
%patch1 -p 1
%patch2
%patch3


%build
make GNATFLAGS='%{GPRbuild_optflags}' LDFLAGS='%{?__global_ldflags}'
make doc


%install
# Pass GPRbuild_optflags here too to ensure that GPRbuild won't recompile anything.
%{make_install} GNATFLAGS='%{GPRbuild_optflags}' prefix=%{_prefix} libdir=%{_libdir} gprdir=%{_GNAT_project_dir}


%check
make tests GNATFLAGS='%{GPRbuild_optflags} -cargs -fPIE'
%{_rpmconfigdir}/check-rpaths


%files
%{_libdir}/*.so.*
%license COPYING
%doc AUTHORS

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/%{name}
%{_GNAT_project_dir}/*
%doc README TODO doc/html examples


%changelog
* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Feb 03 2018 Björn Persson <Bjorn@Rombobjörn.se> - 0.3.4-4
- Switched to building with GPRbuild as project file support was removed from
  Gnatmake in GCC 8.

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun Feb 05 2017 Björn Persson <Bjorn@Rombobjörn.se> - 0.3.4-1
- Upgraded to version 0.3.4.
- Excluded ppc64le because of a suspected endianness bug in Libgnat.

* Mon Jul 11 2016 Björn Persson <Bjorn@Rombobjörn.se> - 0.3.3-1
- Upgraded to version 0.3.3.

* Tue Feb 02 2016 Björn Persson <Bjorn@Rombobjörn.se> - 0.3.1-3
- Rebuilt with GCC 6 prerelease.

* Tue Jun 16 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Mar 31 2015 Björn Persson <bjorn@rombobjörn.se> - 0.3.1-1
- Upgraded to version 0.3.1.

* Sat Feb 07 2015 Björn Persson <bjorn@rombobjörn.se> - 0.2.3-5
- Rebuilt with GCC 5.0.0.

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Apr 10 2014 Björn Persson <bjorn@rombobjörn.se> - 0.2.3-2
- Rebuilt with GCC 4.9.0 prerelease.

* Wed Jan 29 2014 Björn Persson <bjorn@rombobjörn.se> - 0.2.3-1
- Upgraded to version 0.2.3.

* Sun Jul 28 2013 Björn Persson <bjorn@rombobjörn.se> - 0.2.2-2
- Use %%doc now that documentation directories are unversioned.

* Thu May 9 2013 Björn Persson <bjorn@rombobjörn.se> - 0.2.2-1
- ready to be submitted for review
